function OvaBTVTuner(){ };

OvaBTVTuner.prototype._EVENT_CHECK_ACCESS = "onTVTunerCheckAccess";
OvaBTVTuner.prototype._EVENT_BEFORE_TUNING = "onTVTunerBeforeTuning";
OvaBTVTuner.prototype._EVENT_AFTER_TUNING = "onTVTunerAfterTuning";
OvaBTVTuner.prototype._EVENT_ACTIVATE = "onTVTunerActivate";
OvaBTVTuner.prototype._EVENT_DEACTIVATE = "onTVTunerDeactivate";

OvaBTVTuner.prototype.create = function(handler, defaultAccess){
    this._currentSlot = null;
    this._lastSlot = null;
    this._lastChannel = null;
    this._epg = null;
    this._active = false;
    this._reasonCode = null;
    this._handler = null;
    this._defaultAccess = false;
    /* In fase di init this._handler risulta essere uguale a this._defaultHandler */
    this._defaultHandler = handler;
    this.setDefaultAccess(defaultAccess);
    this.setHandler(handler);
};

OvaBTVTuner.prototype.getReasonCode = function(){
    return this._reasonCode;
};
OvaBTVTuner.prototype.refresh = function(){
    var slot = this._epg.getSelected();
    this._tuneTo(slot);
};
OvaBTVTuner.prototype.setActive = function(val){
    if (this._active == val) 
        return;
    this._active = val;
    if (this._active) {
        this._callEventHandler(this._EVENT_ACTIVATE);
        this.refresh();
    }
    else {
        this._clearProgramChangeTimer();
        this._callEventHandler(this._EVENT_DEACTIVATE);
    }
};
OvaBTVTuner.prototype.getActive = function(){
    return this._active;
};
OvaBTVTuner.prototype.prevChannel = function(){
    var slot = this._epg.prevChannel();
    this._tuneTo(slot);
};
OvaBTVTuner.prototype.nextChannel = function(){
    var slot = this._epg.nextChannel();
    this._tuneTo(slot);
};
OvaBTVTuner.prototype.lastChannel = function(){
    if (this._lastChannel == null) 
        return;
    var slot = this._epg.jumpToChannelByRecid(this._lastChannel.recid);
    this._tuneTo(slot);
};
OvaBTVTuner.prototype.hasChannelByRecid = function(chanRecid){
    return (this._epg.channelRecidToIndex(chanRecid) != null);
};
OvaBTVTuner.prototype.hasChannelByNumber = function(chanNum){
    return (this._epg.channelNumberToIndex(chanNum) != null);
};
OvaBTVTuner.prototype.jumpToChannelByRecid = function(chanRecid){
//     omc.logger.addEntry("chanRecid: "+chanRecid);
    var slot = this._epg.jumpToChannelByRecid(chanRecid);
//     omc.logger.addEntry("chanRecid: "+chanRecid);
    this._tuneTo(slot);
};
OvaBTVTuner.prototype.jumpToChannelByNumber = function(chanNum){
    var slot = this._epg.jumpToChannelByNumber(chanNum);
    this._tuneTo(slot);
};
OvaBTVTuner.prototype.scan = function(){
    var slot = this._epg.scanChannels(this, this._canAccess, this.fw.getOSD().getTime());
    this._tuneTo(slot, false);
};

OvaBTVTuner.prototype.getCurrentChannel = function(){
    if (this._currentSlot == null) 
        return null;
    return this._currentSlot.channel;
};
OvaBTVTuner.prototype.setEPG = function(val){
    this._epg = val;
};
OvaBTVTuner.prototype.getEPG = function(){
    return this._epg;
};
OvaBTVTuner.prototype.setApp = function(val){
    this._handler = val;
};
OvaBTVTuner.prototype.getApp = function(){
    return this._handler;
};
OvaBTVTuner.prototype.setHandler = function(val){
    this._handler = val;
};
OvaBTVTuner.prototype.getHandler = function(){
    return this._handler;
};
OvaBTVTuner.prototype.getDefaultHandler = function(){
    return this._defaultHandler;
};

OvaBTVTuner.prototype.setDefaultAccess = function(val){
    this._defaultAccess = val;
};

OvaBTVTuner.prototype.getDefaultAccess = function(){
    return this._defaultAccess;
};

OvaBTVTuner.prototype.getAccessFlag = function(code){
    var access = false;
    if (code == null) {
        code = this._reasonCode;
    }
    switch (code) {
        case this._defaultHandler.AC_DEFAULT_ACCESS_GRANT:
        case this._defaultHandler.AC_CHECK_OVERRIDDEN:
        case this._defaultHandler.AC_PROGRAM_UNAVAILABLE:
        case this._defaultHandler.AC_ACCESS_GRANTED:
            access = true;
            break;
        case this._defaultHandler.AC_NOT_RATED_FOR_PROGRAM:
        case this._defaultHandler.AC_DEFAULT_ACCESS_DENY:
        case this._defaultHandler.AC_CHANNEL_BLOCKED_FOR_ACCOUNT:
        case this._defaultHandler.AC_CHANNEL_BLOCKED_FOR_USER:
        case this._defaultHandler.AC_NOT_RATED_FOR_CHANNEL:
        case this._defaultHandler.AC_PROGRAM_NOT_SUBSCRIBED:
        case this._defaultHandler.AC_CHANNEL_UNAVAILABLE:
        case this._defaultHandler.AC_PROGRAM_CANCELLED:
        case this._defaultHandler.AC_CHANNEL_OFFLINE:
            access = false;
            break;
    }
    return access;
};
OvaBTVTuner.prototype._canAccess = function(slot){
    var code = this._checkAccess(slot);
    return this.getAccessFlag(code);
};
OvaBTVTuner.prototype._checkAccess = function(slot){
    var allow = this._callEventHandler(this._EVENT_CHECK_ACCESS, slot);
    if (allow == null) {
        allow = (this._defaultAccess) ? this._defaultHandler.AC_DEFAULT_ACCESS_GRANT : this._defaultHandler.AC_DEFAULT_ACCESS_DENY;
    }
    return allow;
};
OvaBTVTuner.prototype.overrideAccessCheck = function(){
    this._tuneTo(this._currentSlot, true);
};

OvaBTVTuner.prototype._tuneTo = function(newSlot, skipAccessCheck){
    if (!this._active) 
        return;
    this._clearProgramChangeTimer();
    if (skipAccessCheck) {
        this._reasonCode = this._defaultHandler.AC_CHECK_OVERRIDDEN;
    }
    else {
        this._reasonCode = this._checkAccess(newSlot);
    }
    var cancel = this._callEventHandler(this._EVENT_BEFORE_TUNING, newSlot, this._currentSlot, this._reasonCode);
    if (cancel) {
        return;
    }
    if (this._currentSlot && this._currentSlot.channel && newSlot && newSlot.channel) {
        var currentChannelRecid = this._currentSlot.channel.recid;
        var newChannelRecid = newSlot.channel.recid;
        if (currentChannelRecid != newChannelRecid) {
            this.setLastChannel(this._currentSlot.channel);
        }
    }
    this._setCurrentSlot(newSlot);
    if (this.getAccessFlag(this._reasonCode)) {
        this._tune(newSlot.channel);
    }
    this._callEventHandler(this._EVENT_AFTER_TUNING, newSlot, this._lastSlot, this._reasonCode);
    this._setProgramChangeTimer(newSlot);
};

OvaBTVTuner.prototype._tune = function(channel){
    var macrovision = false;
    if (!channel) {
        return;
    }
    if (channel.chanType != "PORTAL") {
        var schd = this._epg._chanSchds[channel.recid];
        if (schd && schd[0]) {
            macrovision = schd[0].program.macrovision;
        }
        if (macrovision == undefined || macrovision == false) {
            macrovision = channel.macrovision;
        }
        var vc = this.fw.getVideoControl();
        var asset = new Object();
        asset.hostname = channel.url;
		omc.logger.addEntry("************************************************* asset.hostname="+asset.hostname);
        if (channel.chanType == "DVBT") {
            asset.protocol = 'dvb';
            asset.isLocal = channel.isLocal;
        }
        else {
            asset.protocol = 'vsb';
        }
        asset.ecmPort = channel.ecmInfo;
        asset.useMacrovision = macrovision;
        vc.setMacrovision(macrovision);

	vc.load(asset);
    } 
};

OvaBTVTuner.prototype._setProgramChangeTimer = function(slot){
    if (slot != null && slot.program != null) {
        var slotEndTime = slot.program.enddate;
        var now = this.fw.getOSD().getTime();
        var timeToEnd = slotEndTime - now;
        if (timeToEnd > 0) {
            this._programChangeTimerId = this.fw.getTimer().setTimeout(timeToEnd, this.eventProgramChanged, this);
        }
        else {
        }
    }
};
OvaBTVTuner.prototype._clearProgramChangeTimer = function(){
    if (this._programChangeTimerId) {
        this.fw.getTimer().clearTimeout(this._programChangeTimerId);
        this._programChangeTimerId = null;
    }
};
OvaBTVTuner.prototype.eventProgramChanged = function(){
	omc.logger.addEntry("### OvaBTVTuner.eventProgramChanged ###");
    var slot = this._currentSlot;
    if (slot != null && slot.channel) {
        this._epg.jumpToChannelByRecid(slot.channel.recid);
    }
    this._tuneTo(this._epg.getSelected(), false);
    this.fw.getEventManager().handleEvent("eventProgramChanged", this._reasonCode, slot);
};

OvaBTVTuner.prototype.eventEPGUpdated = function(){
    var slot = this._currentSlot;
    if (slot != null && slot.channel) 
        this.jumpToChannelByRecid(slot.channel.recid);
};

OvaBTVTuner.prototype.setLastChannel = function(chan){
    if (!chan || this._lastChannel == chan) 
        return;
    if (chan.chanType != "BRKR") {
        this._lastChannel = chan;
    }
};
OvaBTVTuner.prototype._setCurrentSlot = function(newSlot){
    if (this._lastSlot != this._currentSlot) {
        this._lastSlot = this._currentSlot;
    }
    this._currentSlot = new Object();
    for (var i in newSlot) 
        this._currentSlot[i] = newSlot[i];
};

OvaBTVTuner.prototype._callEventHandler = function(handlerName){
    if (this._handler == null) {
        return null;
    }
    else {
        var handler = this._handler[handlerName];
    }
    if (handler == null) {
        return null;
    }
    var args = [];
    args.push(this);
    for (var i = 1; i < arguments.length; i++) {
        args.push(arguments[i]);
    }
    return handler.apply(this._handler, args);
};






//################################## TILAB #########################################
