function OvaUtil(){
}

OvaUtil.prototype.create = function(){
    this._systemResources = this.fw.createResourceStrings();
    this._dateFormatters = new Array();
    this._utc_dateFormatters = new Array();
    this._sprintfFormatters = new Array();
};

OvaUtil.prototype._INDENT = ' ';
OvaUtil.prototype._DATE_NUMBER = 1000000000000;
OvaUtil.prototype.niceText = function(obj){
    if (typeof(obj) == 'string') {
        return '"' + obj + '"';
    }
    var q = [{
        obj: obj,
        level: 0
    }];
    var item = null, txt = '';
    while (q.length > 0) {
        item = q.shift();
        if (typeof(item) == 'string') {
            txt += item;
        }
        else {
            this._expandNiceText(item.obj, item.level, q);
        }
    }
    return txt;
};
OvaUtil.prototype._expandNiceText = function(obj, level, q){
    switch (typeof(obj)) {
        case 'number':
            if (isFinite(obj) && obj >= this._DATE_NUMBER) {
                q.unshift('*' + this.niceDate(obj) + '*');
            }
            else {
                q.unshift(obj + '');
            }
            return;            break;
        case 'boolean':
            q.unshift(obj + '');
            return;            break;
        case 'string':
            q.unshift('"' + obj + '"');
            return;            break;
        case 'undefined':
            return;            break;
        case 'function':
            q.unshift('*function*');
            break;
    }
    if (obj === null || obj === undefined) {
        q.unshift('' + obj);
        return;
    }
    if (obj instanceof Date) {
        q.unshift(this.niceDate(obj));
        return;
    }
    if (obj instanceof Boolean || obj instanceof Number) {
        q.unshift(obj.toString());
        return;
    }
    if (obj instanceof String) {
        q.unshift('"' + obj.toString() + '"');
        return;
    }
    var indent = '';
    for (var i = 0; i < level; i++) {
        indent += this._INDENT;
    }
    var innerIndent = indent + this._INDENT;
    if (obj.toNiceString) {
        var str = obj.toNiceString();
        str = str.split('\n').join('\n' + indent);
        q.unshift(str);
        return;
    }
    if (obj instanceof Array) {
        if (obj.length == 0) {
            q.unshift('[]');
            return;
        }
        var ins = 0;
        q.splice(ins, 0, '[\n');
        for (var i = 0; i < obj.length; i++) {
            ins++;
            q.splice(ins, 0, innerIndent + i + ':');
            ins++;
            q.splice(ins, 0, {
                obj: obj[i],
                level: level + 1
            });
            ins++;
            q.splice(ins, 0, '\n');
        }
        ins++;
        q.splice(ins, 0, indent + ']');
        return;
    }
    var eCount = 0;
    var prop;
    for (var e in obj) {
        prop = obj[e];
        if (typeof(prop) != 'function' && !(prop instanceof Function)) {
            eCount++;
            break;
        }
    }
    if (eCount == 0) {
        q.unshift('{}');
        return;
    }
    var ins = 0;
    var prop;
    q.splice(ins, 0, '{\n');
    for (var e in obj) {
        prop = obj[e];
        if (typeof(prop) != 'function' && !(prop instanceof Function)) {
            ins++;
            q.splice(ins, 0, innerIndent + e + ':');
            ins++;
            q.splice(ins, 0, {
                obj: prop,
                level: level + 1
            });
            ins++;
            q.splice(ins, 0, '\n');
        }
    }
    ins++;
    q.splice(ins, 0, indent + '}');
};
OvaUtil.prototype.niceDate = function(d, format){
    if (!(d instanceof Date)) {
        var d = new Date(d);
    }
    var year = d.getUTCFullYear();
    var month = d.getUTCMonth() + 1;
    if (month < 10) 
        month = '0' + month;
    var date = d.getUTCDate();
    if (date < 10) 
        date = '0' + date;
    var hours = d.getUTCHours();
    if (hours < 10) 
        hours = '0' + hours;
    var minutes = d.getUTCMinutes();
    if (minutes < 10) 
        minutes = '0' + minutes;
    var seconds = d.getUTCSeconds();
    if (seconds < 10) 
        seconds = '0' + seconds;
    var milli = d.getUTCMilliseconds();
    if (milli < 10) 
        milli = '0' + milli;
    return (year + '-' + month + '-' + date + ' ' + hours + ':' + minutes + ':' + seconds + '.' + milli);
};
OvaUtil.prototype._compile_formatStr = function(formatStr, utc){
    formatStr = formatStr.replace(/"/g, "\\\"");
    var prior = "";
    var index = formatStr.indexOf("HH");
    if (index >= 0) {
        if (formatStr.indexOf("AM") != -1) {
            if (utc) {
                prior += "var ampm = date.getUTCHours() < 12 ? \"AM\" : \"PM\";";
                prior += "var hours = date.getUTCHours();if (hours > 12) hours -= 12;";
            }
            else {
                prior += "var ampm = date.getHours() < 12 ? \"AM\" : \"PM\";";
                prior += "var hours = date.getHours();if (hours > 12) hours -= 12;";
            }
            formatStr = formatStr.replace(/AM/g, "\",ds.localiseDateString(ampm,\"time\"),\"");
            formatStr = formatStr.replace(/HH/g, "\",ds.localiseNumber(ds.padString(hours, 2, \"0\", null)),\"");
        }
        else {
            if (utc) {
                formatStr = formatStr.replace(/HH/g, "\",ds.localiseNumber(ds.padString(date.getUTCHours(), 2, \"0\", null)),\"");
            }
            else {
                formatStr = formatStr.replace(/HH/g, "\",ds.localiseNumber(ds.padString(date.getHours(), 2, \"0\", null)),\"");
            }
        }
    }
    if (utc) {
        formatStr = formatStr.replace(/DY/g, "\",ds.localiseDateString(date.getUTCDay(),\"dayshort\"),\"");
        formatStr = formatStr.replace(/MON/g, "\",ds.localiseDateString(ds.padString(date.getUTCMonth(), 2, \"0\",null),\"monthshort\"),\"");
        formatStr = formatStr.replace(/MM/g, "\",ds.localiseNumber(ds.padString(date.getUTCMonth()+1, 2, \"0\",null)),\"");
        formatStr = formatStr.replace(/DD/g, "\",ds.localiseNumber(ds.padString(date.getUTCDate(), 2, \"0\",null)),\"");
        formatStr = formatStr.replace(/YYYY/g, "\",ds.localiseNumber(date.getUTCFullYear()),\"");
        formatStr = formatStr.replace(/YY/g, "\",ds.localiseNumber(\"\" + date.getUTCFullYear()).substring(2),\"");
        formatStr = formatStr.replace(/MI/g, "\",ds.localiseNumber(ds.padString(date.getUTCMinutes(), 2, \"0\", null)),\"");
        formatStr = formatStr.replace(/SS/g, "\",ds.localiseNumber(ds.padString(date.getUTCSeconds(), 2, \"0\", null)),\"");
    }
    else {
        formatStr = formatStr.replace(/DY/g, "\",ds.localiseDateString(date.getDay(),\"dayshort\"),\"");
        formatStr = formatStr.replace(/MON/g, "\",ds.localiseDateString(ds.padString(date.getMonth(), 2, \"0\",null),\"monthshort\"),\"");
        formatStr = formatStr.replace(/MM/g, "\",ds.localiseNumber(ds.padString(date.getMonth()+1, 2, \"0\",null)),\"");
        formatStr = formatStr.replace(/DD/g, "\",ds.localiseNumber(ds.padString(date.getDate(), 2, \"0\",null)),\"");
        formatStr = formatStr.replace(/YYYY/g, "\",ds.localiseNumber(date.getFullYear()),\"");
        formatStr = formatStr.replace(/YY/g, "\",ds.localiseNumber(\"\" + date.getFullYear()).substring(2),\"");
        formatStr = formatStr.replace(/MI/g, "\",ds.localiseNumber(ds.padString(date.getMinutes(), 2, \"0\", null)),\"");
        formatStr = formatStr.replace(/SS/g, "\",ds.localiseNumber(ds.padString(date.getSeconds(), 2, \"0\", null)),\"");
    }
    formatStr = "compiledDateStr = function(ds, date){ " + prior + " return \"\".concat(" + "\"" + formatStr + "\");};compiledDateStr";
    return eval(formatStr);
};
OvaUtil.prototype.formatDate = function(date, formatStr){
    var func = this._dateFormatters[formatStr];
    if (func == null) {
        func = this._compile_formatStr(formatStr, false);
        this._dateFormatters[formatStr] = func;
    }
    return func(this, date);
};
OvaUtil.prototype.formatUTCDate = function(date, formatStr){
    var func = this._utc_dateFormatters[formatStr];
    if (func == null) {
        func = this._compile_formatStr(formatStr, true);
        this._utc_dateFormatters[formatStr] = func;
    }
    return func(this, date);
};
OvaUtil.prototype.formatSplice = function(index, pattern, replace, formatStr){
    return formatStr.substr(0, index).concat(replace, formatStr.substr(index + pattern.length));
};
OvaUtil.prototype.localiseNumber = function(num){
    var localisedNumber = "";
    var numberArray = this.fw.getLocale().getNumbers();
    var str = String(num);
    for (i = 0; i < str.length; i++) {
        c = str.substring(i, i + 1);
        if (numberArray != null) 
            localisedNumber += numberArray[c];
        else 
            localisedNumber += c;
    }
    return localisedNumber;
};
OvaUtil.prototype.localiseDateString = function(num, type){
    var datearray = null;
    switch (type.toLowerCase()) {
        case "dayshort":
            datearray = this.fw.getLocale().getDays("short");
            break;
        case "daylong":
            datearray = this.fw.getLocale().getDays("long");
            break;
        case "monthshort":
            datearray = this.fw.getLocale().getMonths("short");
            break;
        case "monthlong":
            datearray = this.fw.getLocale().getMonths("long");
            break;
        case "time":
            datearray = this.fw.getLocale().getTimeSymbols();
            break;
    }
    var localisedString = (datearray != null) ? datearray[num] : num;
    return localisedString;
};
OvaUtil.prototype.padString = function(num, w, pad, padAfter){
    str = String(num);
    while (str.length < w) {
        if (padAfter) {
            str += pad
        }
        else {
            str = pad + str;
        }
    }
    return str;
};
OvaUtil.prototype.niceHTML = function(val){
    if (typeof(val) != 'string') {
        val = this.niceString(val);
    }
    val = val.replace(/^(\s*\S+\:)/mg, '<strong>$1</strong>');
    return '<pre>' + val + '</pre>';
};

OvaUtil.prototype.argsToArr = function(args){
    var arr = [];
    for (var i = 0; i < args.length; i++) {
        arr.push(args[i]);
    }
    return arr;
};

OvaUtil.prototype.wrap = function(i, n){
    var i = i % n;
    if (i >= 0) {
        return i;
    }
    else {
        return i + n;
    }
};
OvaUtil.prototype.binSearch = function(arr, comp, startIndex, endIndex){
    if (arguments.length == 2) {
        startIndex = 0;
        endIndex = arr.length - 1;
    }
    for (;;) {
        if (startIndex > endIndex) {
            if (endIndex == arr.length - 1) {
                return {
                    found: false,
                    index: null,
                    lower: endIndex,
                    upper: Number.POSITIVE_INFINITY
                };
            }
            else 
                if (startIndex == 0) {
                    return {
                        found: false,
                        index: null,
                        lower: Number.NEGATIVE_INFINITY,
                        upper: startIndex
                    };
                }
                else {
                    return {
                        found: false,
                        index: null,
                        lower: endIndex,
                        upper: startIndex
                    };
                }
        }
        var mid = Math.floor((startIndex + endIndex) / 2);
        var compValue = comp(arr[mid]);
        if (compValue == 0) {
            return {
                found: true,
                index: mid,
                lower: mid,
                upper: mid
            };
        }
        else 
            if (compValue == -1) {
                endIndex = mid - 1;
            }
            else 
                if (compValue == 1) {
                    startIndex = mid + 1;
                }
                else 
                    if (compValue == null) {
                        return {
                            found: false,
                            index: null,
                            lower: startIndex,
                            upper: endIndex
                        };
                    }
                    else {
                        throw new Error("OvaUtil.binSearch() do not understand return value from the compare function: " + compValue);
                    }
    }
};
OvaUtil.prototype.parseSearchParams = function(searchString){
    var result = new Object();
    if (searchString == '') {
        return result;
    }
    searchString = searchString.substr(1);
    var pairs = searchString.split('&');
    var nameValue = /^([^=]+)(.*)$/;
    var regResult;
    for (var i = 0; i < pairs.length; i++) {
        regResult = pairs[i].match(nameValue);
        if (regResult == null) {
            continue;
        }
        if (regResult.length == 3) {
            if (regResult[2] == '') {
                result[regResult[1]] = true;
            }
            else {
                result[regResult[1]] = regResult[2].substr(1);
            }
        }
    }
    return result;
};
OvaUtil.prototype.arrayToAssocArray = function(arr, keyFunc, valFunc){
    if (typeof(keyFunc) == 'string') {
        keyFunc = arguments.callee.createPickProp(keyFunc);
    }
    else 
        if (typeof(keyFunc) != 'function' && !(keyFunc instanceof Function)) {
            throw new Error('OvaUtil.arrayToAssocArray: 2nd argument must be a function or a property name');
            return;
        }
    if (valFunc == null) {
        valFunc = arguments.callee.ITEM;
    }
    else 
        if (typeof(valFunc) == 'string') {
            valFunc = arguments.callee.createPickProp(valFunc);
        }
        else 
            if (typeof(valFunc) != 'function' && !(valFunc instanceof Function)) {
                throw new Error('OvaUtil.arrayToAssocArray: 3rd argument must be a function or a property name or null');
                return;
            }
    var ret = {}, item;
    for (var i = 0; i < arr.length; i++) {
        item = arr[i];
        ret[keyFunc(item, i) + ''] = valFunc(item, i);
    }
    return ret;
};
OvaUtil.prototype.arrayToAssocArray.INDEX = function(item, index){
    return index;
};
OvaUtil.prototype.arrayToAssocArray.ITEM = function(item, index){
    return item;
};
OvaUtil.prototype.arrayToAssocArray.createPickProp = function(propName){
    return function(item, index){
        return item[propName];
    }
};
OvaUtil.prototype.formToURL = function(url, form){
    var l = form.getLength();
    if (l == 0) 
        return url;
    var field = form.getField(0);
    if (url.indexOf('?') >= 0) 
        url += '&' + encodeURIComponent(field.name) + '=' + encodeURIComponent(field.value);
    else 
        url += '?' + encodeURIComponent(field.name) + '=' + encodeURIComponent(field.value);
    for (var i = 1; i < l; i++) {
        field = form.getField(i);
        url += '&' + encodeURIComponent(field.name) + '=' + encodeURIComponent(field.value);
    }
    return url;
};
OvaUtil.prototype.sprintf_float = function(n, iPrecision){
    var iCount;
    var iPower = Math.pow(10, iPrecision);
    var mArgument = (Math.round(parseFloat(n) * iPower) / iPower).toString();
    var aFloatParts = mArgument.split('.');
    if (iPrecision > 0) {
        if (aFloatParts.length == 1) 
            aFloatParts[1] = '';
        for (iCount = aFloatParts[1].length; iCount < iPrecision; iCount++) 
            aFloatParts[1] += '0';
        mArgument = aFloatParts[0].concat('.', aFloatParts[1]);
    }
    else {
        mArgument = aFloatParts[0];
    }
    return mArgument;
};
OvaUtil.prototype._compile_sprintf = function(sFormat){
    var iCount, iPadLength, aMatch, iMatchIndex = 1;
    var bAlignLeft, sPad, iWidth, iPrecision, sType;
    sFormat = sFormat.replace(/"/g, "\\\"");
    var re = /%(-)?(0| |'.)?(\d+)?(\.\d*)?([bcdfosxX]{1})/;
    while (re.test(sFormat)) {
        aMatch = re.exec(sFormat);
        bAlignLeft = (aMatch[1] == '-');
        sPad = (aMatch[2] == '' ? ' ' : aMatch[2]);
        if (!sPad) 
            sPad = "";
        if (sPad.substring(0, 1) == "'") {
            sPad = sPad.substring(1);
        }
        iWidth = (aMatch[3] > 0 ? parseInt(aMatch[3]) : 0);
        if (!aMatch[4]) {
            aMatch[4] = "";
        }
        iPrecision = (aMatch[4].length > 1 ? parseInt(aMatch[4].substring(1)) : 6);
        sType = aMatch[5];
        if (!sType) {
            sType = "";
        }
        switch (sType) {
            case 'f':
                mArgument = "ds.sprintf_float(aArgs[" + iMatchIndex + "]," + iPrecision + ")";
                break;
            case 'b':
                mArgument = "parseInt(aArgs[" + iMatchIndex + "]).toString(2)";
                break;
            case 'c':
                mArgument = "String.fromCharCode(parseInt(aArgs[" + iMatchIndex + "]))";
                break;
            case 'd':
                mArgument = "aArgs[" + iMatchIndex + "].toString()";
                break;
            case 'o':
                mArgument = "parseInt(aArgs[" + iMatchIndex + "]).toString(8)";
                break;
            case 'x':
                mArgument = "parseInt(aArgs[" + iMatchIndex + "]).toString(16)";
                break;
            case 'X':
                mArgument = "parseInt(aArgs[" + iMatchIndex + "]).toString(16).toUpperCase()";
                break;
            default:
                mArgument = "aArgs[" + iMatchIndex + "].toString()";
        }
        if ('fbdoxX'.indexOf(sType) != -1) {
            sFormat = sFormat.replace(re, "\",ds.padString(" + mArgument + "," + iWidth + ", \"" + sPad + "\", " + bAlignLeft + "),\"");
        }
        else {
            sFormat = sFormat.replace(re, "\"," + mArgument + ",\"");
        }
        ++iMatchIndex;
    }
    sFormat = "\"" + sFormat + "\"";
    sFormat = "compiledSprintf = function( ds, aArgs ){ return \"\".concat(" + sFormat + ");};compiledSprintf";
    return eval(sFormat);
};
OvaUtil.prototype.sprintf = function(){
    if (arguments.length < 2) 
        return '';
    var sFormat = arguments[0];
    var func = this._sprintfFormatters[sFormat];
    if (func == null) {
        func = this._compile_sprintf(sFormat);
        this._sprintfFormatters[sFormat] = func;
    }
    return func(this, arguments);
};
OvaUtil.prototype.padLeft = function(s, pad, length){
    s = '' + s;
    if (length == null) 
        return s;
    if (!isFinite(length)) 
        return s;
    while (s.length < length) 
        s = pad + s;
    return s;
};
OvaUtil.prototype.findInterval = function(intervals, val, startFieldName, endFieldName){
    if (startFieldName == null) 
        startFieldName = 'program.startdate';
    if (endFieldName == null) 
        endFieldName = 'program.enddate';
    var find = function(interval){
        var startTime = interval.program.startdate;
        var endTime = interval.program.enddate;
        if (startTime <= val && val < endTime) {
            return 0;
        }
        else 
            if (val < startTime) {
                return -1;
            }
            else 
                if (endTime <= val) {
                    return 1;
                }
    };
    var findNext = function(){
        var nextEvent = null;
        var nextStart = -1;
        var eventFound = false;
        for (var i = 0; i < intervals.length; i++) {
            var startTime = (intervals[i]).program.startdate;
            if (startTime >= val && (nextStart == -1 || startTime < nextStart)) {
                nextEvent = i;
                nextStart = startTime;
                eventFound = true;
            }
        }
        return {
            found: eventFound,
            index: nextEvent,
            lower: nextEvent,
            upper: nextEvent
        };
    };
    var searchRes = this.binSearch(intervals, find);
    if (!searchRes.found) {
        searchRes = findNext();
    }
    return searchRes;
};
OvaUtil.prototype.makeTime = function(time, methodName){
    if (methodName == null) 
        methodName = 'OvaUtil.makeTime';
    var ret;
    if (time == null) {
        ret = this.fw.getOSD().getTime();
    }
    else 
        if (typeof(time) != 'number') {
            try {
                ret = time.getTime();
            } 
            catch (e) {
                throw new Error('OvaUtil.makeTime) Cannot convert time "' + time + '" in ' + methodName + '()');
            }
        }
        else 
            ret = time;
    return ret;
};
OvaUtil.prototype.arraySelect = function(arr, filterFunc, filterObj){
    var ret = [];
    var item;
    if (filterObj != null) {
        for (var i = 0; i < arr.length; i++) {
            item = arr[i];
            if (filterFunc.call(filterObj, item)) 
                ret.push(item);
        }
    }
    else {
        for (var i = 0; i < arr.length; i++) {
            item = arr[i];
            if (filterFunc(item)) 
                ret.push(item);
        }
    }
    return ret;
};
OvaUtil.prototype.getIndexByName = function(arr, key){
    var selectedIndex = 0;
    for (var i = 0; i < arr.length; i++) {
        if (arr[i].name == key) 
            selectedIndex = i;
    }
    return selectedIndex;
};
OvaUtil.prototype.truncateString = function(strToTruncate, length, toPad){
    var truncatedString;
    if (strToTruncate.length <= length) {
        truncatedString = strToTruncate;
    }
    else {
        if (toPad) 
            truncatedString = strToTruncate.substring(0, length).concat('...');
        else 
            truncatedString = strToTruncate.substring(0, length);
    }
    return truncatedString;
};
OvaUtil.prototype.argsToArr = function(args){
    var arr = [];
    for (var i = 0; i < args.length; i++) 
        arr.push(args[i]);
    return arr;
};
OvaUtil.prototype.trim = function(strToTrim){
    var leading = new RegExp("^\\s*");
    var trailing = new RegExp("\\s*$");
    strToTrim = strToTrim.replace(leading, "");
    strToTrim = strToTrim.replace(trailing, "");
    return strToTrim;
};
OvaUtil.prototype.getURLEncoded = function(stringVariable){
    var encodedString = stringVariable;
    if (stringVariable) {
        encodedString = encodeURIComponent(stringVariable);
        if (encodedString) {
            encodedString = encodedString.replace("%3A", "%3a");
        }
    }
    return encodedString;
};
OvaUtil.prototype.appendParamToURL = function(url, pname, pval){
    if (url.indexOf("?") == -1) 
        url += "?";
    else 
        url += "&";
    url += encodeURIComponent(pname);
    url += "=";
    url += encodeURIComponent(pval);
    return url;
};
OvaUtil.prototype.isValidPin = function(pinString){
    var illegalChars = this._systemResources.getLabel("OVA/COMMON/VALIDATION", "ILLEGAL_CHARS_PIN");
    return this._isValid(illegalChars, pinString, false);
};
OvaUtil.prototype.isValidEmail = function(mailString){
    var idx = mailString.indexOf('@');
    if (idx == -1) {
        return false;
    }
    if (mailString.indexOf('@', idx + 1) != -1) {
        return false;
    }
    if (mailString.indexOf('.', idx) == -1) {
        return false;
    }
    var illegalChars = this._systemResources.getLabel("OVA/COMMON/VALIDATION", "ILLEGAL_CHARS_EMAIL");
    return this._isValid(illegalChars, mailString, false);
};
OvaUtil.prototype.isValidInputText = function(inputString, allowWhiteSpace){
    var illegalChars = this._systemResources.getLabel("OVA/COMMON/VALIDATION", "ILLEGAL_CHARS_TEXTINPUT");
    return this._isValid(illegalChars, inputString, allowWhiteSpace);
};
OvaUtil.prototype._isValid = function(patterns, validateString, allowWhiteSpaces){
    var isValid = true;
    if (!allowWhiteSpaces) {
        if (validateString.search(/\s/) != -1) {
            isValid = false;
        }
    }
    if (isValid) {
        for (i = 0; i < validateString.length; i++) {
            var strChar = validateString.charCodeAt(i);
            for (j = 0; j < patterns.length; j++) {
                if (strChar == patterns.charCodeAt(j)) {
                    isValid = false;
                    break;
                }
            }
            if (!isValid) 
                break;
        }
    }
    return isValid;
};
OvaUtil.prototype.isValidNumber = function(inputNum){
    var validNum = true;
    var legalNum = this._systemResources.getLabel("OVA/COMMON/VALIDATION", "LEGAL_NUMBERS");
    if (inputNum.search(/\s/) == -1) {
        validNum = !(this._isValid(legalNum, inputNum, true));
    }
    else {
        validNum = false;
    }
    return validNum;
};
OvaUtil.prototype.getValidDate = function(time){
    if (typeof(time) == 'string') {
        this.fw.getDebug().logWarning('OvaUtil: time is a string. use Date.parse() for ', time);
        time = Date.parse(time);
    }
    else 
        if (typeof(time) != 'number') {
            this.fw.getDebug().logWarning('OvaUtil: time is not a number. use OSD for ', time);
            time = this.fw.getOSD().getTime();
        }
    return time;
};
OvaUtil.prototype.parseInteger = function(s, defaultVal){
    if (s == null) 
        return defaultVal;
    var ret = parseInt(s, 10);
    if (isFinite(ret)) 
        return ret;
    return defaultVal;
};

OvaUtil.prototype.parseBoolean = function(s, defaultVal){
    if (s == null) 
        return defaultVal;
    if (typeof(s) == 'string') {
        s = s.toLowerCase();
        switch (s) {
            case 'yes':
            case 'true':
                return true;
                break;
            case 'no':
            case 'false':
                return false;
                break;
            default:
                return defaultVal;
        }
    }
    else 
        if (typeof(s) == 'number') {
            return (s != 0);
        }
        else 
            if (typeof(s) == 'boolean') {
                return s;
            }
            else {
                return defaultVal;
            }
};

OvaUtil.prototype.getParamValue = function(s, key){
    var value = null;
    if (s) {
        var params = s.split("&");
        for (i = 0; i < params.length; i++) {
            param = params[i].split("=");
            if (param[0] == key) {
                value = param[1];
                break;
            }
        }
    }
    return value;
};
