OvaVideoControl.prototype.VIDEO_OFF = 0;
OvaVideoControl.prototype.VIDEO_FULLSCREEN = 1;
OvaVideoControl.prototype.VIDEO_BACKGROUND = 2;
OvaVideoControl.prototype.VIDEO_WINDOW = 3;
OvaVideoControl.prototype.VIDEO_ALPHA = 4;
OvaVideoControl.prototype.AUDIO_STEREO = 0;
OvaVideoControl.prototype.AUDIO_MONO_MIX = 3;
OvaVideoControl.prototype.AUDIO_MONO_LEFT = 2;
OvaVideoControl.prototype.AUDIO_MONO_RIGHT = 1;
OvaVideoControl.prototype.MODE_STOP = null;
OvaVideoControl.prototype.MODE_PLAY = 1;
OvaVideoControl.prototype.MODE_PAUSE = 0;
OvaVideoControl.prototype.MODE_RWD = -2;
OvaVideoControl.prototype.MODE_FFWD = 2;
OvaVideoControl.prototype.STATE_STOPPED = 0;
OvaVideoControl.prototype.STATE_PLAYING = 1;
OvaVideoControl.prototype.STATE_PAUSED = 2;
OvaVideoControl.prototype.STATE_REWINDING = 3;
OvaVideoControl.prototype.STATE_FAST_FORWARDING = 4;

function OvaVideoControl(){ }

OvaVideoControl.prototype.create = function(){
    this._isPC = this.fw.getOSD().isPC();
    this._videoMode = this.VIDEO_OFF;
    this._videoStatus = this.STATE_STOPPED;
    this._audioChannel = this.AUDIO_STEREO;
    this._videoPollTimer = null;
    this._playRate = 1;
    this._busyState = false;
    this._subtitlesEnabled = false;
    this._updateSubtitles = false;
    this._availableSubtitleLanguages = '';
    this._asset = null;
    this._videoURL = null;
    this._isVOD = false;
    this._macrovision = false;
    this._curStreamURL = null;
    this._curLoopCount = 0;
    this._curAudioPid = 0;
    this._curAlpha = 0;
    this._curVolume = 0;
    this._isMute = false;
    this._primaryAudioLanguage = '';
    this._loading = false;
    this._retries = 0;
    this._MAX_RETRIES = 5;
    this.VIDEO_RETRY_RATE = 1000;
    this.VIDEO_LOAD_TIMEOUT = eval(this.fw.getConfig().VIDEO_LOAD_TIMEOUT);
    this.VIDEO_AVAILABLE_RATE = 40;
    this._videoErrorDeferTimer = null;
    this.DRM_ENABLED = eval(this.fw.getConfig().ENABLE_DRM);
    this._loadTimer = null;
};

OvaVideoControl.prototype.getURL = function(){
    return this._curStreamURL;
};

OvaVideoControl.prototype.load = function(asset){
    if (!asset) {
        return false;
    }
    if (!asset.hostname) {
        return false;
    }
    asset.protocol = (!asset.protocol) ? 'vsb' : asset.protocol.toLowerCase();
    this._isVOD = (asset.protocol == 'rtsp' || asset.protocol == 'vsi') ? true : false;
    if (this._isVOD && !asset.assetName) {
        return false;
    }
    asset.serverType = (!asset.serverType) ? 'OVS' : asset.serverType;
    asset.vodLoopCount = (!asset.vodLoopCount) ? 0 : asset.vodLoopCount;
    asset.vodPosition = (!asset.vodPosition) ? 0 : asset.vodPosition;
    asset.pid = (!asset.pid) ? 0 : asset.pid;
    asset.authTkt = (!asset.authTkt) ? null : asset.authTkt;
    this._videoURL = this._constructURL(asset);
    this._asset = asset;
    if (!this._isPC) {
        try {
            omc.stream.enableStateChangedEvents(videocontrol_omcStreamStateChanged);
        } 
        catch (e) {
            this.fw.getEventManager().handleEvent("eventVideoInitFailed", e);
        }
    }
    if (this.DRM_ENABLED) {
        this._loadTimer = this.fw.getTimer().setTimeout(this.VIDEO_LOAD_TIMEOUT, this.fw.getDRM()._loadVideo, this.fw.getDRM(), this._asset);
    }
    else {
        this._loadTimer = this.fw.getTimer().setTimeout(this.VIDEO_LOAD_TIMEOUT, this._loadVideo, this);
    }
    return true;
};

OvaVideoControl.prototype._unload = function(){
    if (this.STATE_STOPPED) {
        return;
    }
    this._curStreamURL = null;
    this._curLoopCount = 0;
    if (this._loadTimer) {
        this.fw.getTimer().clearTimeout(this._loadTimer);
        this._loadTimer = null;
    }
    if (!this._isPC && this._videoStatus) {
        try {
            omc.stream.unload();
        } 
        catch (e) {
        }
    }
    if (!this._isPC) {
        try {
            omc.stream.enableStateChangedEvents();
        } 
        catch (e) {
            this.fw.getEventManager().handleEvent("eventVideoInitFailed", e);
        }
    }
    this._videoStatus = this.STATE_STOPPED;
    this._busyState = false;
};

OvaVideoControl.prototype.setWindow = function(x, y, width, height){
    if (this._videoMode == this.VIDEO_WINDOW) {
        if (this._videoWindowX == x && this._videoWindowY == y && this._videoWindowWidth == width && this._videoWindowHeight == height) {
            return;
        }
    }
    if (!this._isPC) {
        try {
            omc.video.window(x, y, width, height);
            omc.video.foreground();
            omc.video.visible(true);
        } 
        catch (e) {
        }
    }
    this._videoMode = this.VIDEO_WINDOW;
    this._videoWindowX = x;
    this._videoWindowY = y;
    this._videoWindowWidth = width;
    this._videoWindowHeight = height;
    this._curAlpha = 0;
};

OvaVideoControl.prototype.videoOff = function(){
    this._curAlpha = 0;
    if (!this._isPC) {
        try {
            omc.video.visible(false);
        } 
        catch (e) {
        }
    }
    this._videoMode = this.VIDEO_OFF;
};
OvaVideoControl.prototype.setPosition = function(position){
    if (!this._isPC) {
        try {
            omc.stream.setPosition(position * 1000);
        } 
        catch (e) {
        }
    }
};
OvaVideoControl.prototype.getPosition = function(){
    if (!this._isPC) {
        return Math.floor(omc.stream.getPosition() / 1000);
    }
    else {
        return 0;
    }
};
OvaVideoControl.prototype.getState = function(){
    return this._videoStatus;
};
OvaVideoControl.prototype.getVersion = function(){
    if (!this._isPC) {
        try {
            return omc.stb.getVersion();
        } 
        catch (e) {
        }
    }
};
OvaVideoControl.prototype.getMode = function(){
    return this._videoMode;
};
OvaVideoControl.prototype.fullScreen = function(){
    if (this._videoMode == this.VIDEO_FULLSCREEN) {
        return;
    }
    this._videoMode = this.VIDEO_FULLSCREEN;
    if (!this._isPC) {
        try {
            omc.video.fullscreen();
        } 
        catch (e) {
        }
    }
};

OvaVideoControl.prototype.background = function(key, mask){
    if (this._videoMode == this.VIDEO_BACKGROUND) {
        return;
    }
    this._videoMode = this.VIDEO_BACKGROUND;
    this._backgroundKey = key;
    this._backgroundMask = mask;
    if (!this._isPC) {
        try {
	    /* queste mi fanno apparire le scritte bianche */
// 	    top.getFetcher().sendDebugTrap("Ci sono: ");
            omc.video.setColorKey(key, mask);
            omc.video.background();
            omc.video.fullscreen();
            omc.video.visible(true);
        } 
        catch (e) {
        }
    }
};

OvaVideoControl.prototype.setAlpha = function(alpha){
    if (!this._isPC) {
        try {
            omc.video.setAlpha(alpha);
        } 
        catch (e) {
        }
    }
};
OvaVideoControl.prototype.getAlpha = function(){
    if (!this._isPC) {
        try {
            return omc.video.getAlpha();
        } 
        catch (e) {
        }
    }
    return 0;
};
OvaVideoControl.prototype.setPlayRate = function(playRate){
    if (!this._isVOD && playRate != this.MODE_STOP) {
        this.fw.getDebug().logWarning("can't change rate of btv stream");
        return;
    }
    if (this._playRate == playRate) {
        return;
    }
    this._playRate = playRate;
    if (this._playRate == this.MODE_STOP) {
        this._unload();
        this._videoStatus = this.STATE_STOPPED;
    }
    else 
        if (this._playRate == this.MODE_PLAY) {
            this._videoStatus = this.STATE_PLAYING;
        }
        else 
            if (this._playRate == this.MODE_PAUSE) {
                this._videoStatus = this.STATE_PAUSED;
            }
            else 
                if (this._playRate >= this.MODE_FFWD) {
                    this._videoStatus = this.STATE_FAST_FORWARDING;
                }
                else 
                    if (this._playRate <= this.MODE_RWD) {
                        this._videoStatus = this.STATE_REWINDING;
                    }
    if (!this._isPC) {
        try {
            if (playRate == null) {
                omc.stream.unload();
            }
            else {
                omc.stream.setPlayRate(playRate);
            }
        } 
        catch (e) {
        }
    }
};
OvaVideoControl.prototype.getPlayRate = function(){
    return this._playRate;
};
OvaVideoControl.prototype.setMacrovision = function(val){
    if (!this._isPC) {
        try {
            omc.video.setCopyProtection(val);
            this._macrovision = val;
        } 
        catch (e) {
        }
    }
};
OvaVideoControl.prototype.getMacrovision = function(){
    return this._macrovision;
};
OvaVideoControl.prototype.toggleAudioChannel = function(){
};
OvaVideoControl.prototype.setAudioChannel = function(audioChannel){
    this._audioChannel = audioChannel;
};
OvaVideoControl.prototype.getAudioChannel = function(){
    return this._audioChannel;
};
OvaVideoControl.prototype.setAudioPID = function(pid){
    if (!this._isPC && this._videoStatus != this.STATE_STOPPED) {
        try {
            var descs = omc.audio.getAvailableDescriptors();
            for (index = 0; index < descs.length; index++) {
                if (pid == descs[index].pid) {
                    descs[index].pid = pid;
                    omc.audio.selectDescriptor(descs[index]);
                    break;
                }
            }
        } 
        catch (e) {
        }
    }
};
OvaVideoControl.prototype.setAudioLanguage = function(lang){
    var returnCode = 0;
    if (!this._isPC) {
        var audioDescs = this.getAvailableDescriptors();
        var index;
        try {
            for (index = 0; index < audioDescs.length; index++) {
                if (lang == audioDescs[index].language) {
                    returnCode = omc.audio.selectDescriptor(audioDescs[index]);
                    break;
                }
            }
        } 
        catch (e) {
        }
    }
    return returnCode;
};
OvaVideoControl.prototype.getAvailableAudioLanguages = function(){
    var langs = null;
    if (!this._isPC) {
        try {
            var descs = omc.audio.getAvailableDescriptors();
            if (descs.length > 0) {
                langs = new Array();
                for (desc in descs) {
                    langs.push(descs[descs].language);
                }
            }
        } 
        catch (e) {
        }
    }
    return langs;
};
OvaVideoControl.prototype.setPrimaryAudioLanguage = function(lang){
    if (!this._isPC) {
        try {
            var langs = new Array();
            langs.push(lang);
            omc.audio.setPreferredLanguages(langs);
            return true;
        } 
        catch (e) {
        }
    }
    return false;
};
OvaVideoControl.prototype.setMute = function(val){
    this._isMute = val;
};
OvaVideoControl.prototype.getMute = function(){
    return this._isMute;
};
OvaVideoControl.prototype.setVolume = function(val){
    this._volume = val;
};
OvaVideoControl.prototype.getVolume = function(){
    return this._volume;
};
OvaVideoControl.prototype.getDefaultSubtitleLanguage = function(){
    var lang = null;
    if (!this._isPC && this._subtitlesEnabled) {
        try {
            var langs = omc.subtitles.getPreferredLanguages();
            if (langs.length > 0) {
                lang = langs[0];
            }
        } 
        catch (e) {
        }
    }
    return lang;
};
OvaVideoControl.prototype.setDefaultSubtitleLanguage = function(langCode){
    if (!this._isPC && this._subtitlesEnabled) {
        try {
            var langs = new Array();
            langs.push(langCode);
            omc.subtitles.setPreferredLanguages(langs);
        } 
        catch (e) {
        }
    }
};
OvaVideoControl.prototype.getCurrentSubtitleLanguage = function(){
    var lang = null;
    if (!this._isPC && this._subtitlesEnabled) {
        try {
            var desc = omc.subtitles.getCurrentDescriptor();
            if (desc) {
                lang = desc.language;
            }
        } 
        catch (e) {
        }
    }
    return lang;
};
OvaVideoControl.prototype.setCurrentSubtitleLanguage = function(langCode){
    var returnCode = false;
    if (!this._isPC && this._subtitlesEnabled) {
        try {
            var descs = omc.subtitles.getAvailableDescriptors();
            var index;
            for (index = 0; index < descs.length; index++) {
                if (langCode == descs[index].language) {
                    returnCode = true;
                    omc.subtitles.selectDescriptor(descs[index]);
                    break;
                }
            }
        } 
        catch (e) {
        }
    }
    return returnCode;
};
OvaVideoControl.prototype.getAvailableSubtitleLanguages = function(){
    var langs = null;
    if (!this._isPC) {
        try {
            var descs = omc.subtitles.getAvailableDescriptors();
            if (descs.length > 0) {
                var index;
                langs = new Array();
                for (index = 0; index < descs.length; index++) {
                    langs.push(descs[index].language);
                }
            }
        } 
        catch (e) {
        }
    }
    return langs;
};
OvaVideoControl.prototype.setSubtitlesEnabled = function(enabled){
    this._subtitlesEnabled = enabled;
    this._updateSubtitles = true;
    try {
        omc.subtitles.setEnabled(this._subtitlesEnabled);
    } 
    catch (e) {
        return;
    }
};
OvaVideoControl.prototype.getSubtitlesEnabled = function(){
    return this._subtitlesEnabled;
};
OvaVideoControl.prototype._checkSubtitleAvailability = function(){
    if (!this._isPC) {
        var oldSubtitleLangs = this._availableSubtitleLanguages;
        var newSubtitleLangsArr = this.getAvailableSubtitleLanguages();
        if (oldSubtitleLangs != this._availableSubtitleLanguages) {
            return this.fw.getEventManager().handleVideoEvent("eventSubtitleAvailabilityChanged", newSubtitleLangsArr);
        }
    }
    return false;
};
OvaVideoControl.prototype._constructURL = function(asset){
    var videoURL = '';
    if (this._isVOD) {
        videoURL = "vsi://" + asset.hostname + "/" + asset.assetName;
        if (asset.authTkt) {
            videoURL += "?" + asset.authTkt;
        }
    }
    else {
        if (asset.protocol == 'dvb') {
            if (asset.isLocal) {
                videoURL = "dvb://" + asset.hostname;
            }
            else {
                videoURL = "dvb://" + asset.hostname;
            }
        }
        else {
            videoURL = "vsb:" + asset.hostname;
            if (asset.ecmPort && asset.ecmPort.length > 0) {
                var firstDash = asset.ecmPort.indexOf('-');
                var casid = asset.ecmPort.substring(0, firstDash);
                var ecmAddr = asset.ecmPort.substring(firstDash + 1);
                videoURL += "?casid=" + casid + "&ecm_addr=" + ecmAddr;
            }
        }
    }
    return videoURL;
};
OvaVideoControl.prototype._loadVideo = function(){
    this._busyState = false;
    this._networkBlocked = 0;
    if (this._loadTimer) {
        this.fw.getTimer().clearTimeout(this._loadTimer);
        this._loadTimer = null;
    }
    if (this._videoURL != this._curStreamURL) {
        var loop = false;
        if (this._isVOD) {
            this.setAudioPID(this._asset.pid);
            loop = (this._asset.vodLoopCount > 0) ? true : false;
            this._curLoopCount = this._asset.vodLoopCount;
        }
        if (this._videoStatus != this.STATE_STOPPED) {
            this.setPlayRate(this.MODE_STOP);
        }
        if (!this._isPC) {
            try {
            	
// 		this.sendDebugTrap("omc.stream.load_metodo:_loadVideo");
		this.fw.setLastUrlVideo(this._videoURL);
		if(this.fw.OMC_LOGGER_ENABLED)omc.logger.addEntry("#####################################################################################");
		if(this.fw.OMC_LOGGER_ENABLED)omc.logger.addEntry("#####################################################################################");
		if(this.fw.OMC_LOGGER_ENABLED)omc.logger.addEntry("#######################  OvaVideoControl._loadVideo -this._videoURL: "+this._videoURL);
		if(this.fw.OMC_LOGGER_ENABLED)omc.logger.addEntry("#####################################################################################");
		if(this.fw.OMC_LOGGER_ENABLED)omc.logger.addEntry("#####################################################################################");
                omc.stream.load(this._videoURL, loop, this._asset.vodPosition * 1000, this._curAudioPid);
            } 
            catch (e) {
            	omc.logger.addEntry("ECCEZIONE OvaVideoControl._loadVideo "+e.message);
// 		this.sendDebugTrap("errore_omc.stream.load_metodo:_loadVideo_"+e);
            }
            
        }
    }
    this._videoStatus = this.STATE_PLAYING;
    this._playRate = 1;
    this._curStreamURL = this._videoURL;
    this._loading = true;
    this._updateSubtitles = true;
};
OvaVideoControl.prototype._reload = function(){
    if (this._videoStatus == this.STATE_PLAYING) {
        try {
            omc.stream.unload();
        } 
        catch (e) {
        }
    }
    this._playRate = 1;
    this._videoStatus = this.STATE_PLAYING;
    if (!this._isPC) {
        var loop = false;
        if (this._isVOD) {
            loop = (this._asset._curLoopCount > 0) ? true : false;
        }
        try {
            omc.stream.load(this._videoURL, loop, this._asset.vodPosition * 1000, this._curAudioPid);
        } 
        catch (e) {
        }
    }
};
function videocontrol_omcStreamStateChanged(omcState){
    top.getFramework().getVideoControl()._checkVideoState(omcState);
}

OvaVideoControl.prototype._checkVideoState = function(ovcState){
    if (this._videoErrorDeferTimer != null) {
        this.fw.getTimer().clearTimout(this._videoErrorDeferTimer);
        this._videoErrorDeferTimer = null;
    }
    switch (ovcState) {
        case omc.stream.STATE_IDLE:
        case omc.stream.STATE_PAUSED:
            this._busyState = false;
            if (!this._isVOD) {
                return this.fw.getEventManager().handleVideoEvent("eventStreamLost", "OVC" + ovcState);
            }
            break;
        case omc.stream.STATE_PLAYING:
            this._busyState = false;
            this._retries = 0;
            if (this._updateSubtitles) {
                this._updateSubtitles = false;
                try {
                    omc.subtitles.setEnabled(this._subtitlesEnabled);
                } 
                catch (e) {
                    return;
                }
            }
            if (this._loading) {
                this._loading = false;
                return this.fw.getEventManager().handleVideoEvent("eventStreamAcquired");
            }
            break;
        case omc.stream.STATE_END_OF_STREAM:
            if (this._curLoopCount != 0) {
                var consumed = this.fw.getEventManager().handleVideoEvent("eventVideoLoop");
                if (consumed) {
                    return true;
                }
                if (this._curLoopCount != -1) {
                    this._curLoopCount--;
                }
                this._reload();
            }
            else {
                if (!this.busyState) {
                    this._busyState = true;
                    return this.fw.getEventManager().handleVideoEvent("eventVideoEnd");
                }
            }
            break;
        case omc.stream.STATE_START_OF_STREAM:
            this.setPlayRate(this.MODE_PLAY);
            return this.fw.getEventManager().handleVideoEvent("eventVideoStart");
            break;
        case omc.stream.STATE_ERROR_TIMEOUT:
            omc.logger.addEntry("----------------------------> STATE ERROR TIMEOUT");
            if (this._isVOD) {
                omc.logger.addEntry("----------------------------> VOD STATE ERROR TIMEOUT");
                this.setPlayRate(this.MODE_STOP);
                this.videoOff();
                return this.fw.getEventManager().handleVideoEvent("eventStreamLost", "OVC" + ovcState);
            }
            else {
                omc.logger.addEntry("----------------------------> BTV STATE ERROR TIMEOUT");
                this._videoErrorDeferTimer = this.fw.getTimer().setTimeout(this.VIDEO_RETRY_RATE, this._handleVideoTimeout, this);
            }
            break;
        case omc.stream.STATE_ERROR_CLIENT:
        case omc.stream.STATE_ERROR_SERVER:
        default:
            this.setPlayRate(this.MODE_STOP);
            this.videoOff();
            return this.fw.getEventManager().handleVideoEvent("eventStreamLost", "OVC" + ovcState);
    }
};
OvaVideoControl.prototype._handleVideoTimeout = function(){
    var videoState = 0;
    if (this._videoErrorDeferTimer != null) {
        this.fw.getTimer().clearTimeout(this._videoErrorDeferTimer);
        this._videoErrorDeferTimer = null;
    }
    try {
        videoState = omc.stream.getState();
    } 
    catch (e) {
    }
    if (videoState == omc.stream.STATE_ERROR_TIMEOUT) {
        if (this._retries <= this._MAX_RETRIES) {
            this._retries++;
            omc.logger.addEntry("RETRY " + this._retries);
            this._reload();
        }
        else {
            retries = 0;
            this.setPlayRate(this.MODE_STOP);
            this.videoOff();
            return this.fw.getEventManager().handleVideoEvent("eventStreamLost", "OVC" + videoState);
        }
    }
};
