OvaListUI.prototype = new OvaBaseUI();
function OvaListUI() {
}
OvaListUI.prototype.create = function(layoutId) {
	this._create(layoutId);
	this._initHotKeys(4);
	this.setChangeUser(this.fw.getChangeUser());
	this._useDOMCache = false;
	this._useDataDOMCache = false;
	this._busyIndicator = false;
	this._useSwitchPoint = false;
	this._refreshTime = this.fw.getConfig().UI_CLOCK_REFRESH_INTERVAL;
};
OvaListUI.prototype.setList = function(list) {
	this._list = list;
	this._useDataDOMCache = false;
	this._useDOMCache = false;
};
OvaListUI.prototype.setUseSwitchPoint = function(switchpoint) {
	this._useSwitchPoint = switchpoint;
};
OvaListUI.prototype.setError = function(error, errorTime) {
	if (this._errorTimerId) {
		this.fw.getTimer().clearTimeout(this._errorTimerId);
		this._errorTimerId = null;
	}
	this._error = error;
	this._errorTime = errorTime;
	this._useDOMCache = false;
	this._useDataDOMCache = false;
};
OvaListUI.prototype.setMessage = function(message, messageTime, drawHotKeys,
		doCancel) {
	if (this._messageTimerId) {
		this.fw.getTimer().clearTimeout(this._messageTimerId);
		this._messageTimerId = null;
	}
	this._message = message;
	this._messageTime = messageTime;
	this._messageDrawHotKeys = drawHotKeys;
	this._messageDoCancel = doCancel;
	this._useDOMCache = false;
	this._useDataDOMCache = false;
};
OvaListUI.prototype.setVideo = function(video) {
	this._video = video;
	var vc = this.fw.getVideoControl();
	vc.load(video);
};
OvaListUI.prototype.redraw = function() {
	var layoutManager = this.fw.getLayoutManager();
	this._drawBusyIndicator();
	if (this._upArrowVisible != null)
		layoutManager.setElementVisible(this._layoutId, "divArrowUp",
				this._upArrowVisible);
	if ((this._downArrowVisible != null))
		layoutManager.setElementVisible(this._layoutId, "divArrowDown",
				this._downArrowVisible);
	if ((this._rightArrowVisible != null))
		layoutManager.setElementVisible(this._layoutId, "divArrowRight",
				this._rightArrowVisible);
	if ((this._leftArrowVisible != null))
		layoutManager.setElementVisible(this._layoutId, "divArrowLeft",
				this._leftArrowVisible);
	if ((this._videoWindowVisible != null))
		layoutManager.setElementVisible(this._layoutId, "videoWindow",
				this._videoWindowVisible);
	if ((this._detailsVisible != null)) {
		layoutManager.setElementVisible(this._layoutId, "ShortDesc",
				this._detailsVisible);
	}
	if ((this._long_detailsVisible != null)) {
		layoutManager.setElementVisible(this._layoutId, "LongDesc",
				this._long_detailsVisible);
	}
	if ((this._detailsVisible == null) && (this._long_detailsVisible == null)) {
		layoutManager.setElementVisible(this._layoutId, "ShortDesc", false);
		layoutManager.setElementVisible(this._layoutId, "LongDesc", false);
	}
	if (this._statusBarVisible != null)
		this._drawStatusBar();
	var status = this.fw.getStatus();
	var user = status.getUser();
	if (!this._curUser || (user != this._curUser)) {
		this._curUser = user;
		if (user && user.length > 15)
			user = user.substring(0, 13) + "..";
		layoutManager.writeBlock(this._layoutId, "user", user, "text");
	}
	if (this._error) {
		this._drawError(this._error);
		this._redrawHotKeys();
		if (this._errorTime) {
			this._errorTimerId = this.fw.getTimer().setTimeout(this._errorTime,
					this._undrawError, this);
			this._errorTime = null;
		}
		return;
	}
	if (this._message) {
		this._drawMessage(this._message);
		this._redrawHotKeys();
		if (this._messageTime) {
			this._messageTimerId = this.fw.getTimer().setTimeout(
					this._messageTime, this._undrawMessage, this);
			this._messageTime = null;
		}
		return;
	} else {
		layoutManager.setElementVisible(this._layoutId, "message", false);
		layoutManager.setElementVisible(this._layoutId, "SwitchPoint", false);
	}
	if (this._pinDialog) {
		this._drawPinDialog(this._pinDialog);
	}
	if (this._pinForm) {
		this._drawPinForm(this._pinForm);
		if (!this._changeUser && !this._pinDialog)
			return;
	} else if (this._searchForm) {
		this._drawSearchForm(this._searchForm);
	} else {
		this._undrawSearchForm(this._searchForm);
	}
	this._redrawByTagName("ova:data", this._list,
			this._elementUI.getListElement, this._elementUI,
			this._useDataDOMCache);
	this._useDataDOMCache = true;
	this._redrawByTagName("ova:label", this._list, this._getLabel, this,
			this._useDOMCache);
	this._redrawByTagName("ova:error", this._list, this._getError, this,
			this._useDOMCache);
	if (!this._clockRefresh) {
		this._drawTime();
	}
	this._redrawHotKeys();
	this._useDOMCache = true;
};
OvaListUI.prototype.playVideo = function() {
	var vc = this.fw.getVideoControl();
	vc.setPlayRate(vc.MODE_PLAY);
};
OvaListUI.prototype.pauseVideo = function() {
	var vc = this.fw.getVideoControl();
	vc.setPlayRate(vc.MODE_PAUSE);
};
OvaListUI.prototype.rewindVideo = function() {
	var vc = this.fw.getVideoControl();
	vc.setPlayRate(vc.MODE_RWD);
};
OvaListUI.prototype.fastForwardVideo = function() {
	var vc = this.fw.getVideoControl();
	vc.setPlayRate(vc.MODE_FFWD);
};
OvaListUI.prototype.stopVideo = function() {
	var vc = this.fw.getVideoControl();
	vc.setPlayRate(vc.MODE_STOP);
};
OvaListUI.prototype.hideVideo = function() {
	var layoutManager = this.fw.getLayoutManager();
	var elem = layoutManager.getElement(this._layoutId, "videoWindow");
	if (elem != null) {
		var vc = this.fw.getVideoControl();
		vc.videoOff();
		vc.setWindow(0, 0, 0, 0, true);
	}
};
OvaListUI.prototype.drawVideo = function() {
	var layoutManager = this.fw.getLayoutManager();
	var elem = layoutManager.getElement(this._layoutId, "videoWindow");
	if (elem != null) {
		var vc = this.fw.getVideoControl();
		if (vc.getState() == vc.STATE_PLAYING) {
			vc.setWindow(330, 160, 340, 270);
		} else {
			vc.videoOff();
		}
	}
};
OvaListUI.prototype.showVideoError = function() {
	var layoutManager = this.fw.getLayoutManager();
	layoutManager.setElementVisible(this._layoutId,
			"OVA/COMMON/VIDEO/MENU_UNAVAILABLE", true);
	layoutManager.setElementVisible(this._layoutId, "videoWindow", true);
};
OvaListUI.prototype.hideVideoError = function() {
	var layoutManager = this.fw.getLayoutManager();
	layoutManager.setElementVisible(this._layoutId,
			"OVA/COMMON/VIDEO/MENU_UNAVAILABLE", false);
	layoutManager.setElementVisible(this._layoutId, "videoWindow", false);
};
OvaListUI.prototype._drawMessage = function(message) {
	var layoutManager = this.fw.getLayoutManager();
	layoutManager.writeBlock(this._layoutId, "messageTitle", "Message", "text");
	layoutManager.writeBlock(this._layoutId, "messageText", message, "text");
	layoutManager.setElementVisible(this._layoutId, "message", true);
	if (this._messageDrawHotKeys) {
		this.setHotKeyLabel(2, this._resources.getLabel("OVA/COMMON/PIN",
				"accept"));
		this.setHotKeyVisible(2, true);
		this.setHotKeyLabelVisible(2, true);
		this.setHotKeyVisible(3, false);
		this.setHotKeyLabelVisible(3, false);
		if (this._messageDoCancel) {
			this.setHotKeyLabel(1, this._resources.getLabel("OVA/COMMON/PIN",
					"cancel"));
			this.setHotKeyVisible(1, true);
			this.setHotKeyLabelVisible(1, true);
		} else {
			this.setHotKeyVisible(1, false);
			this.setHotKeyLabelVisible(1, false);
		}
	}
};
OvaListUI.prototype._undrawError = function() {
	this._errorTime = null;
	this._errorTimerId = null;
	this._error = null;
	this.redraw();
};
OvaListUI.prototype._undrawMessage = function() {
	this._messageTime = null;
	this._messageTimerId = null;
	this._message = null;
	this.redraw();
};
OvaListUI.prototype._drawError = function(msg) {
	var layoutManager = this.fw.getLayoutManager();
	var data = this._elementUI.getErrorElement(msg);
	var type = data.type;
	var content = data.content;
	var styles = data.styles;
	if (styles.length > 0) {
		content = this._makeStyleString(styles, content);
		type = "html";
	}
	layoutManager.writeBlock(this._layoutId, "messageTitle", "Error", "text");
	layoutManager.writeBlock(this._layoutId, "messageText", content, type);
	layoutManager.setElementVisible(this._layoutId, "message", true);
	layoutManager.setElementVisible(this._layoutId, "hotkey2Image", true);
	layoutManager.writeBlock(this._layoutId, "hotkey2", this._resources
			.getLabel("OVA/COMMON/PIN", "accept"), text);
	layoutManager.setElementVisible(this._layoutId, "hotkey1Image", false);
	layoutManager.setElementVisible(this._layoutId, "hotkey1", false);
	layoutManager.setLayout(this._layoutId);
};
OvaListUI.prototype.setDetailsVisible = function(val) {
	this._detailsVisible = val;
};
OvaListUI.prototype.setLongDetailsVisible = function(val) {
	this._long_detailsVisible = val;
};
OvaListUI.prototype.setVideoWindowVisible = function(val) {
	this._videoWindowVisible = val;
};
OvaListUI.prototype.setUpArrowVisible = function(val) {
	this._upArrowVisible = val;
};
OvaListUI.prototype.setDownArrowVisible = function(val) {
	this._downArrowVisible = val;
};
OvaListUI.prototype.setLeftArrowVisible = function(val) {
	this._leftArrowVisible = val;
};
OvaListUI.prototype.setRightArrowVisible = function(val) {
	this._rightArrowVisible = val;
};
OvaListUI.prototype.setBusyIndicator = function(val) {
	this._busyIndicator = val;
};
OvaListUI.prototype._drawBusyIndicator = function() {
	this.fw.getLayoutManager().setElementVisible(this._layoutId,
			"BusyIndicator", this._busyIndicator);
};
OvaListUI.prototype._drawTime = function() {
	var now = this.fw.getUtil().formatDate(
			new Date(this.fw.getOSD().getTime()), 'HH:MI AM, DY DD');
	if (now != this._lastTime) {
		var layoutManager = this.fw.getLayoutManager();
		layoutManager.writeBlock(this._layoutId, "timestamp", now, "text");
	}
	this._lastTime = now;
	if (this._refreshTime != 0) {
		this._clockRefresh = this.fw.getTimer().setTimeout(
				this._refreshTime * 1000, this._drawTime, this);
	}
};
OvaListUI.prototype._undrawSearchForm = function(searchForm) {
	var layoutManager = this.fw.getLayoutManager();
	var search = layoutManager.getElement(this._layoutId, "slotSelectedSearch");
	search.style.display = 'none';
	var pin = layoutManager.getElement(this._layoutId, "slotSelectedPin");
	pin.style.display = 'none';
	var selCont = layoutManager.getElement(this._layoutId,
			"slotSelectedContent");
	selCont.style.display = 'block';
	layoutManager.setElementVisible(this._layoutId, "slotSelectedPinError",
			false);
};
OvaListUI.prototype._drawSearchForm = function(searchForm) {
	var layoutManager = this.fw.getLayoutManager();
	var selCont = layoutManager.getElement(this._layoutId,
			"slotSelectedContent");
	selCont.style.display = 'none';
	var pin = layoutManager.getElement(this._layoutId, "slotSelectedPin");
	pin.style.display = 'none';
	var search = layoutManager.getElement(this._layoutId, "slotSelectedSearch");
	search.style.display = 'table';
	var layout = layoutManager.getLayout(this._layoutId);
	this._bindForm(this._searchForm, layout);
	layoutManager.focusOn(this._layoutId, "searchInput");
};
OvaListUI.prototype.populateSearchForm = function() {
	if (this._searchForm == null)
		return;
	var layoutManager = this.fw.getLayoutManager();
	var win = layoutManager.getLayout(this._layoutId);
	var form = this._findForm(this._searchForm.getName(), win);
	this._populateForm(this._searchForm, form);
};
OvaListUI.prototype.setSearchForm = function(searchForm) {
	if (this._searchForm != null) {
		var layoutManager = this.fw.getLayoutManager();
		this._unbindForm(this._searchForm, layoutManager
				.getLayout(this._layoutId));
		layoutManager.getLayout(this._layoutId).focus();
	}
	this._searchForm = searchForm;
	this._useDOMCache = false;
	this._useDataDOMCache = false;
};
OvaListUI.prototype.getSearchForm = function() {
	return this._searchForm;
};
OvaListUI.prototype.measureStringWidth = function(text, className) {
	var x = top.layout.measuring.document
			.getElementById("listLayoutMeasureWidth");
	x.className = className;
	x.innerHTML = text;
	return x.offsetWidth;
};
OvaListUI.prototype.truncateStringToFixedWidth = function(strToTruncate, width,
		spanClassID, truncator) {
	for ( var trunc = 0; trunc < 255; ++trunc) {
		if (trunc > 0)
			str = truncator(strToTruncate, strToTruncate.length - trunc, true);
		else
			str = strToTruncate;
		var w = this.measureStringWidth(str, spanClassID);
		if (w <= width)
			return trunc;
	}
	return trunc;
};
OvaListUI.prototype._drawPinDialog = function(pd) {
	var layoutManager = this.fw.getLayoutManager();
	layoutManager.setLayout(this._layoutId);
	if (pd.getMode() != pd.MODE_INACTIVE) {
		this.setHotKeyLabel(1, this._resources.getLabel("OVA/COMMON/PIN",
				"cancel"));
		this.setHotKeyLabel(2, this._resources.getLabel("OVA/COMMON/PIN",
				"accept"));
		this.setHotKeyVisible(1, true);
		this.setHotKeyLabelVisible(1, true);
		this.setHotKeyVisible(2, true);
		this.setHotKeyLabelVisible(2, true);
		this.setHotKeyVisible(3, false);
		this.setHotKeyLabelVisible(3, false);
		layoutManager.setElementVisible(this._layoutId, "SwitchPoint",
				this._useSwitchPoint);
		this._drawPinForm(pd.getPinForm());
		pd.mapEvent("eventKeyHot2", pd.ACTION_ACCEPT);
		pd.mapEvent("eventKeyHot1", pd.ACTION_CANCEL);
		if (pd.getMode() == pd.MODE_ERROR) {
			layoutManager.setElementVisible(this._layoutId,
					"slotSelectedPinError", true);
			layoutManager.focusOn(this._layoutId, "pinInput");
		}
	}
};