#!/bin/sh

mount_usb()
{
	if [ ! -d /tmp/usb1 ] ; then
		echo -e "\n/tmp/usb1 directory not exists: creating it\n"
		mkdir /tmp/usb1
	else
		echo -e "\nUmount existing /tmp/usb1 directory\n"
		cd /tmp
		/bin/umount /tmp/usb1
	fi
	
	mount /dev/sda1 -t vfat /tmp/usb1
	ritorno=$?
	# echo "=========== valore di ritorno = $ritorno  ================"
	if [ $ritorno -ne 0 ];then
		echo -e "\n/dev/sda1 failed"
		mount /dev/sda -t vfat /tmp/usb1
		ritorno=$?
		if [ $ritorno -ne 0 ];then
			echo -e "\n/dev/sda failed"
			echo "=========== mount USB : $ritorno (something wrong) : Aborted procedure ================"
		fi
	fi
	return $ritorno
}

abort_on_error()
{
	cd /tmp
	/bin/gpiotest WRITE 5 0  # reset active
	/bin/gpiotest WRITE 2 1  # disable USBa
	/bin/gpiotest WRITE 3 1  # disable USBb
}

clear_error() 
{
	/bin/zcat /opt/splashes/carica.pcx.gz > /tmp/image1.pcx 2>/dev/null
	/usr/bin/tfbu script /opt/splashes/carica.tfbu 2>/dev/null >/dev/null
}

show_error()
{
	CODE=$1
	/bin/echo "USB upgrade - show_error $CODE"
	/bin/zcat /opt/splashes/usb_errore$CODE.pcx.gz > /tmp/image1.pcx 2>/dev/null
	/bin/zcat /opt/splashes/usb_errore${CODE}_body.pcx.gz > /tmp/image2.pcx 2>/dev/null
	/bin/zcat /opt/splashes/callcenter.pcx.gz > /tmp/image3.pcx 2>/dev/null
	/usr/bin/tfbu script /opt/splashes/generic_3images.tfbu 2>/dev/null >/dev/null
	/bin/rm /tmp/image1.pcx 2>&1 >/dev/null
	/bin/rm /tmp/image2.pcx 2>&1 >/dev/null
	/bin/rm /tmp/image3.pcx 2>&1 >/dev/null
	
	cd /tmp
	/bin/umount /tmp/usb1
	# Now wait for USB stick removal
	let ritorno=0
	while [ $ritorno -eq 0 ]
	do
		/bin/grep -q 'Driver=usb-storage' /proc/bus/usb/devices
		ritorno=$?

		/bin/sleep 3
		/bin/echo "Remove the USB stick for going on! ($ritorno)"
	done
	clear_error
}

/bin/gpiotest WRITE 5 1 # usb reset high
/bin/gpiotest WRITE 2 0 # usbA enable (bottom USB slot on HY100 STB)
/bin/gpiotest WRITE 3 1 # usbB disable

# Wait some time, before USB is actually enabled
/bin/sleep 1

/bin/mount -t usbfs none /proc/bus/usb

/sbin/insmod sd_mod
/sbin/insmod usb-storage

# Wait some time, before the devices have been scanned
/bin/sleep 5

/bin/echo "----------------------------------------------------------"
/bin/cat /proc/bus/usb/devices
/bin/echo "----------------------------------------------------------"
/bin/dmesg | tail
/bin/echo "----------------------------------------------------------"

if [ ! -b /dev/sda ] ; then
	/bin/echo "Node /dev/sda not present: creating it"
	/bin/mknod /dev/sda b 8 0
fi
if [ ! -b /dev/sda1 ] ; then
	/bin/echo "Node /dev/sda1 not present: creating it"
	/bin/mknod /dev/sda1 b 8 1
fi

mount_usb
ritorno=$?
if [ $ritorno -eq 0 ]
then 
	echo "=========== mounting USB OK : $ritorno ================"
else
	# USB key wrong or not correctly mounted. 
	# No error message. Exit the script (go on with normal boot)
	abort_on_error
	exit 1

fi

cd /tmp/usb1
ls
FILE="upgrade-info.txt"
if [ ! -e "$FILE" ]; then
	echo "file '$FILE' not found"
	# VISUALIZZARE errore - informazioni di upgrade non presenti sulla chiavetta USB.
	show_error "020"
	abort_on_error
	exit 1
else
	echo "found file '$FILE'"
	read UPGRADING_FILE <"$FILE"
	echo "found also file '$UPGRADING_FILE'"
	if [ ! -e "$UPGRADING_FILE" ]; then
		echo "file '$UPGRADING_FILE' not found"
		echo "Upgrading procedure aborted"
		# VISUALIZZARE errore: file di upgrade non presente. Procedura di upgrade abortita.
		show_error "021"
		abort_on_error
		exit 1
	else
		# Compute our decimal software version
		FILE_VERSION=$UPGRADING_FILE
		#echo -e "lunghezza = ${#FILE_VERSION}"
		FILE_VERSION=`/bin/echo $UPGRADING_FILE | /bin/sed "s/-/ /g" | /usr/bin/cut -d ' ' -f 2`
		NOME_FILE=`/bin/echo $UPGRADING_FILE | /bin/sed "s/-/ /g" | /usr/bin/cut -d ' ' -f 1`
		# echo -e "\nnome versione = $NOME_FILE $FILE_VERSION\n"
		let NEW_VERSION=`/bin/echo $FILE_VERSION | /bin/sed "s/\./ /g" | /usr/bin/cut -d ' ' -f 1`*10000
		let NEW_VERSION=$NEW_VERSION+`/bin/echo $FILE_VERSION | /bin/sed "s/\./ /g" | /usr/bin/cut -d ' ' -f 2`*100
		let NEW_VERSION=$NEW_VERSION+`/bin/echo $FILE_VERSION | /bin/sed "s/\./ /g" | /usr/bin/cut -d ' ' -f 3`
		
		echo -e "\n========== new SWver found = $NEW_VERSION ============="
		
		RAPPO=`/bin/cat /etc/stbconfig.buildtime|grep PCMGR_SWVER`
		
		SWVER=`/bin/echo $RAPPO |/bin/sed "s/\"/ /g" | /usr/bin/cut -d ' ' -f 2`
		
		let FLASHED_VERSION=`/bin/echo $SWVER | /bin/sed "s/\./ /g" | /usr/bin/cut -d ' ' -f 1`*10000
		let FLASHED_VERSION=$FLASHED_VERSION+`/bin/echo $SWVER | /bin/sed "s/\./ /g" | /usr/bin/cut -d ' ' -f 2`*100
		let FLASHED_VERSION=$FLASHED_VERSION+`/bin/echo $SWVER | /bin/sed "s/\./ /g" | /usr/bin/cut -d ' ' -f 3`
		echo -e "========== flashed version = $FLASHED_VERSION =============\n"
		
		if [ "$NOME_FILE" != "telecomstb" ] ;then
			echo -e "\nWrong file name $NOME_FILE"
			# VISUALIZZARE errore: file di upgrade con nome errato. Procedura di upgrade abortita.
			show_error "022"
			abort_on_error
			exit 1
		fi
		
		
		if [ "$FLASHED_VERSION" -lt "$NEW_VERSION" ] 
		then
			echo -e "\nUPGRADING procedure is starting now !\n"	
		else
			echo -e "\nNO UPGRADE procedure\n"	
			# VISUALIZZARE errore: Release di upgrade minore o uguale a quella in flash. Procedura di upgrade abortita.
			show_error "023"
			abort_on_error
			exit 0
		fi
			
			
		cp /tmp/usb1/$UPGRADING_FILE /tmp/upgrade-image.bin
		
		cd /tmp
		/bin/dd if=upgrade-image.bin of=sign_bin bs=128 count=1
		/bin/dd if=upgrade-image.bin of=upgrade-image.tar.gz bs=128 skip=1
		/bin/rm upgrade-image.bin
		/usr/sbin/checknds upgrade-image.tar.gz sign_bin
		if [ "$?" = 0 ] ; then
			if /bin/zcat upgrade-image.tar.gz | /bin/tar xvf - > /dev/null ; then
				/bin/umount /etc/config 
				/bin/rm upgrade-image.tar.gz
				# Arrange the libled.so path
				/bin/rm -f /tmp/newroot/lib/libled.so
				/bin/ln -s /lib/libPled.so /tmp/newroot/lib/libled.so


				# Draw the "aggiornamento in corso" splash
				/bin/zcat /opt/splashes/aggiornamento_usb.pcx.gz > /tmp/image1.pcx 2>/dev/null
				/bin/zcat /opt/splashes/aggiornamento_usb_body.pcx.gz > /tmp/image2.pcx 2>/dev/null
				/usr/bin/tfbu script /opt/splashes/generic_2images_top.tfbu 2>/dev/null >/dev/null
				/bin/rm /tmp/image1.pcx 2>&1 >/dev/null
				/bin/rm /tmp/image2.pcx 2>&1 >/dev/null
				
				# Remount /tmp, removing possible "noexec" mode
				/bin/mount -o remount,rw /tmp
				
				# Finally launch the upgrade process in chroot.
				# This should terminate with a reboot, so this
				# is the exit point for the script you are reading.
				echo -e "\n\nEnd of checks: now flashing the board and rebooting\n\n"

				/bin/umount /tmp/usb1 
		
				cd /tmp/newroot

				#####################################
				# check for version from untared file
				#####################################
				UPGRADING_FILE=`ls flash-image-*.kr.*`
				if [ ! -e "$UPGRADING_FILE" ]; then
					echo "file '$UPGRADING_FILE' non trovato"
					echo "Upgrading procedure aborted"
					# VISUALIZZARE errore: file di upgrade non presente. Procedura di upgrade abortita.
					show_error "021"
					abort_on_error
					exit 1
				else
					echo "file '$UPGRADING_FILE' trovato !!!"
				fi

				FILE_VERSION=`/bin/echo $UPGRADING_FILE | /bin/sed "s/-/ /g" | /usr/bin/cut -d ' ' -f 3`

				let NEW_VERSION=`/bin/echo $FILE_VERSION | /bin/sed "s/\./ /g" | /usr/bin/cut -d ' ' -f 1`*10000
				let NEW_VERSION=$NEW_VERSION+`/bin/echo $FILE_VERSION | /bin/sed "s/\./ /g" | /usr/bin/cut -d ' ' -f 2`*100
				let NEW_VERSION=$NEW_VERSION+`/bin/echo $FILE_VERSION | /bin/sed "s/\./ /g" | /usr/bin/cut -d ' ' -f 3`
				
				echo -e "========== flashed version = $FLASHED_VERSION ============="
				echo -e "======= new internal SWver = $NEW_VERSION ============="
				
				
				if [ "$FLASHED_VERSION" -lt "$NEW_VERSION" ] 
				then
					echo -e "\nUPGRADING procedure is starting now !\n"	
				else
					echo -e "\nNO UPGRADE procedure\n"	
					# VISUALIZZARE errore: Release di upgrade minore o uguale a quella in flash. Procedura di upgrade abortita.
					show_error "023"
					abort_on_error
					exit 1
				fi
				cd -



				/usr/sbin/chroot /tmp/newroot upgrade.sh "upgrade_via_usb"
			fi
			# Should never come here, anyway turn off the LED
			/usr/sbin/setleds -t sw_upgrade -s 0 > /dev/null
		else
			/usr/sbin/setleds -t sw_upgrade -s 0 > /dev/null
			/bin/echo "NDS signing control failed."
			# VISUALIZZARE errore: check errato della release di upgrade. Procedura di upgrade abortita.
			show_error "024"
			abort_on_error
			exit 1
		fi	

	fi
fi


exit 0

