#!/bin/sh
#
# Application manager wrapper script

. /etc/stb.env

# Check for manual launch
if [ "$1" = "manual" ] ; then
    if pidof fresco ; then
        /usr/bin/killall fresco appMan
        /bin/echo "Waiting for fresco termination..."
        /bin/sleep 10
    fi
    /bin/echo "PCMGR_APPMAN_ENABLE=0" >> /tmp/stbconfig.volatile
    PCMGR_APPMAN_ENABLE=1
    /etc/init.d/mrua-insmod restart
    export AM_DEB_NAME=
else
    export AM_DEB_NAME=/tmp/appMan.log
fi

if [ "$PCMGR_APPMAN_ENABLE" = "0" ]
then
    while /bin/true
    do
        /bin/sleep 1000
    done
else

    # Now compute the right FRESCO_OMC_OUTPUT_OPTIONS, based on the template.
    FRESCO_OMC_OUTPUT_OPTIONS=`/etc/init.d/get-output-options`
    /bin/echo FRESCO_OMC_OUTPUT_OPTIONS=\"$FRESCO_OMC_OUTPUT_OPTIONS\" >> /tmp/stbconfig.volatile

    # If the application manager has restarted, (and we have been respawned by init),
    # execute some cleaning operation, before relaunching it.
    if [ "$APPMAN_RESTARTED" = "1" ] ; then
        # Reloading the smartcard module (try to fix the activation sequence bug)
        MSG="Reloading smartcard module before relaunching appman."
        /bin/echo $MSG ; /bin/echo $MSG >> /tmp/appMan.log
        /etc/init.d/smartcard restart

        # Reload the Sigma modules. This is needed in case of segmentation fault of fresco/OMC.
        MSG="Removing Sigma modules."
        /bin/echo $MSG ; /bin/echo $MSG >> /tmp/appMan.log
        /etc/init.d/mrua-insmod stop
        /bin/sleep 2
        # Now verify that the modules have been really removed. Otherwise, retry
        if /sbin/lsmod | /bin/grep -q "em8xxx\|llad" ; then 
            MSG="Could not remove Sigma modules: retrying."
            /bin/echo $MSG ; /bin/echo $MSG >> /tmp/appMan.log
            /etc/init.d/mrua-insmod stop
            /bin/sleep 2
        fi
        # Now verify that the modules have been really removed. Otherwise, reboot
        if /sbin/lsmod | /bin/grep -q "em8xxx\|llad" ; then 
            MSG="Could not remove Sigma modules: rebooting."
            /bin/echo $MSG ; /bin/echo $MSG >> /tmp/appMan.log
            /bin/sleep 1
            /sbin/reboot
        fi
        MSG="Reloading Sigma modules."
        /bin/echo $MSG ; /bin/echo $MSG >> /tmp/appMan.log
        /etc/init.d/mrua-insmod start
    fi

    # Read NDS parameters from the secure flash area
    NDS_STB_ID=`/sbin/secsi_man secsi_read_ID`
    NDS_KEY_IN_BOX=`/sbin/secsi_man secsi_read_secret_key`

    

    export NDS_STB_ID
    export NDS_KEY_IN_BOX

    export AM_DEB_LEVEL=20
    export MAX_START_PPPOE=$PCMGR_MAX_START_PPPOE_SECS
    export RX_LIMIT_PPPOE=10
    export TX_LIMIT_PPPOE=10
    export TIME_WATCH_DOG=60
    export MAX_RETRY_PROC=5
    export CONFIG_STB_TIMEOUT=30
    export STANDBY_TIME_REBOOT=$FPSTANDBY_REBOOT_TIMEOUT
    export MIN_TIME_DEBOUNCING=400000
    export ENTER_ADMIN_PAGE=$ENTER_ADMIN_PAGE
    export CFG_SERVER_SOCKET=/tmp/serversocket
    export START_IN_STANDBY_MODE=$START_IN_STANDBY_MODE
    export FRESCO_PATH=/usr/bin/fresco

    # Push platform
    export PUSH_WEB_URL="http://127.0.0.1:1980"
    export MSG_QUEUE_ID=$PUSH_QUEUE_ID
    export ENCR_KEY=$PUSH_ENCR_KEY
    export DEFAULT_PUSHD_PORT=$PUSHD_PORT
    export DEFAULT_PUSHD_PATH=$PUSHD_PATH
    export PUSHD_ENABLE=$PUSHD_ENABLE
    
    # DTT offline
    export TILAB_ROOT=$DTT_OFFLINE_TILAB_ROOT


    # Launch the daemon checking for ethernet cable disconnection (error 300)
    #/etc/init.d/chklink start

    # Finally launch the application manager
    exec /usr/bin/appMan
fi


