#!/bin/sh
#
# LED blinking utility
#
# By pierpaolo.glave@pirelli.com
#
# Usage: call this script with the same parameters as for "setleds", but:
#        - don't pass any "-s" option
#        - optionally add "-p PERIOD"  (where PERIOD is the blinking period in msec)
#
# The blinking goes on endlessly.
# To stop it: 
# - Launch this script in background
# - Save its pid using $!
# - Kill it when needed

# Default values:
PERIOD=1000
SETLED_ARGS=""

# Parse parameters
until [ -z "$1" ]
do
    case "$1" in
    "-s")
        # Discard it, and the next argument (the number) too 
        shift 
        ;;
    "-p")
        if [ -n "$2" ] ; then 
            shift
            PERIOD=$1
        fi
        ;;
    *)
        SETLED_ARGS=$SETLED_ARGS" $1"   
        ;; 
    esac
    shift 
done

let PERIOD_US=PERIOD*1000
while /bin/true
do
    /usr/sbin/setleds $SETLED_ARGS -s 1 > /dev/null
    /bin/usleep $PERIOD_US  
    /usr/sbin/setleds $SETLED_ARGS -s 0 > /dev/null
    /bin/usleep $PERIOD_US  
done 
