#!/bin/sh
#
# LED blinking utility
#
# By Rappo , scopiazzato da ledblink.sh di pierpaolo.glave@pirelli.com
#
# Usage: call this script with the same parameters as for "setleds", but:
#        - don't pass any "-s" option
#        - optionally add "-p0 PERIOD_0 and -p1 PERIOD_1"  
#          (where PERIOD_0 + PERIOD_1 is the blinking period in msec: 
#          PERIOD_1 is the time for the leds ON and PERIOD_0 is the time 
#          for the leds OFF)
#	 - up to 5 leds can be selected to blink: specify their name after
#          -t1 , -t2 , -t3 , -t4 , -t5  parameters.
#	 - the colour and the brightness are the same for all the leds
#	   specified. 
#
# The blinking goes on endlessly.
# To stop it: 
# - Launch this script in background
# - Save its pid using $!
# - Kill it when needed

# Default values:
PERIOD_0=500
PERIOD_1=500
SETLED_ARGS=""
NAME1=""
NAME2=""
NAME3=""
NAME4=""
NAME5=""

# Parse parameters
until [ -z "$1" ]
do
    case "$1" in
    "-s")
        # Discard it, and the next argument (the number) too 
        shift 
        ;;
    "-t1")
        if [ -n "$2" ] ; then 
            shift
            NAME1=$1
        fi
        ;;
    "-t2")
        if [ -n "$2" ] ; then 
            shift
            NAME2=$1
        fi
        ;;
    "-t3")
        if [ -n "$2" ] ; then 
            shift
            NAME3=$1
        fi
        ;;
    "-t4")
        if [ -n "$2" ] ; then 
            shift
            NAME4=$1
        fi
        ;;
    "-t5")
        if [ -n "$2" ] ; then 
            shift
            NAME5=$1
        fi
        ;;
    "-p0")
        if [ -n "$2" ] ; then 
            shift
            PERIOD_0=$1
        fi
        ;;
    "-p1")
        if [ -n "$2" ] ; then 
            shift
            PERIOD_1=$1
        fi
        ;;
    *)
        SETLED_ARGS=$SETLED_ARGS" $1"   
        ;; 
    esac
    shift 
done

let PERIOD_0_MS=PERIOD_0*1000
let PERIOD_1_MS=PERIOD_1*1000
while /bin/true
do
	if [ "$NAME1" != "" ] ; then
	    /usr/sbin/setleds $SETLED_ARGS -t $NAME1 -s 1 > /dev/null
	fi
	if [ "$NAME2" != "" ] ; then
	    /usr/sbin/setleds $SETLED_ARGS -t $NAME2 -s 1 > /dev/null
	fi
	if [ "$NAME3" != "" ] ; then
	    /usr/sbin/setleds $SETLED_ARGS -t $NAME3 -s 1 > /dev/null
	fi
	if [ "$NAME4" != "" ] ; then
	    /usr/sbin/setleds $SETLED_ARGS -t $NAME4 -s 1 > /dev/null
	fi
	if [ "$NAME5" != "" ] ; then
	    /usr/sbin/setleds $SETLED_ARGS -t $NAME5 -s 1 > /dev/null
	fi

    /bin/usleep $PERIOD_1_MS  

	if [ "$NAME1" != "" ] ; then
	    /usr/sbin/setleds $SETLED_ARGS -t $NAME1 -s 0 > /dev/null
	fi
	if [ "$NAME2" != "" ] ; then
	    /usr/sbin/setleds $SETLED_ARGS -t $NAME2 -s 0 > /dev/null
	fi
	if [ "$NAME3" != "" ] ; then
	    /usr/sbin/setleds $SETLED_ARGS -t $NAME3 -s 0 > /dev/null
	fi
	if [ "$NAME4" != "" ] ; then
	    /usr/sbin/setleds $SETLED_ARGS -t $NAME4 -s 0 > /dev/null
	fi
	if [ "$NAME5" != "" ] ; then
	    /usr/sbin/setleds $SETLED_ARGS -t $NAME5 -s 0 > /dev/null
	fi

    /bin/usleep $PERIOD_0_MS  
done 
